==> monica-3.7.0p2.tgz: www/monica/resources/lang/no/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hvordan var dagen din? Du kan vurdere den én gang om dagen.',
    'journal_come_back' => 'Takk. Kom tilbake i morgen for å vurdere dagen din igjen.',
    'journal_description' => 'Merk: Journalen viser både manuelle journaloppføringer og automatiske innlegg som aktiviteter registrert på dine kontakter. Du kan slette journaloppføringer, men for å fjerne aktiviteter må du fjerne dem fra kontaktens side.',
    'journal_add' => 'Legg til journaloppføring',
    'journal_edit' => 'Rediger en journaloppføring',
    'journal_empty' => 'Tom journal',
    'journal_created_at' => 'Opprettet {date}',
    'journal_created_automatically' => 'Opprettet automatisk',
    'journal_entry_type_journal' => 'Journalinnlegg',
    'journal_entry_type_activity' => 'Aktivitet',
    'journal_entry_rate' => 'Du vurderte din dag.',
    'journal_add_comment' => 'Vil du utdype i en kommentar (valgfritt)?',
    'journal_show_comment' => 'Vis kommentar',
    'entry_delete_success' => 'Journaloppføringen har blitt slettet.',
    'journal_add_title' => 'Tittel (valgfritt)',
    'journal_add_date' => 'Dato',
    'journal_add_post' => 'Innlegg',
    'journal_add_cta' => 'Lagre',
    'journal_blank_cta' => 'Legg til din første journaloppføring',
    'journal_blank_description' => 'Journalen lar deg skrive innlegg slik at du husker hva som skjer i løpet av en dag.',
    'delete_confirmation' => 'Er du sikker på at du vil slette denne journaloppføringen?',
];

==> monica-4.1.2.tgz: www/monica/resources/lang/no/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hvordan var dagen din? Du kan vurdere den én gang om dagen.',
    'journal_come_back' => 'Takk. Kom tilbake i morgen for å vurdere dagen din igjen.',
    'journal_description' => 'Merk: Journalen viser både manuelle journaloppføringer og automatiske innlegg som aktiviteter registrert på dine kontakter. Du kan slette journaloppføringer, men for å fjerne aktiviteter må du fjerne dem fra kontaktens side.',
    'journal_add' => 'Legg til journaloppføring',
    'journal_edit' => 'Rediger en journaloppføring',
    'journal_empty' => 'Tom journal',
    'journal_created_at' => 'Opprettet {date}',
    'journal_created_automatically' => 'Opprettet automatisk',
    'journal_entry_type_journal' => 'Journalinnlegg',
    'journal_entry_type_activity' => 'Aktivitet',
    'journal_entry_rate' => 'Du vurderte din dag.',
    'journal_add_comment' => 'Vil du utdype i en kommentar (valgfritt)?',
    'journal_show_comment' => 'Vis kommentar',
    'entry_delete_success' => 'Journaloppføringen har blitt slettet.',
    'journal_add_title' => 'Tittel (valgfritt)',
    'journal_add_date' => 'Dato',
    'journal_add_post' => 'Innlegg',
    'journal_add_cta' => 'Lagre',
    'journal_blank_cta' => 'Legg til din første journaloppføring',
    'journal_blank_description' => 'Journalen lar deg skrive innlegg slik at du husker hva som skjer i løpet av en dag.',
    'delete_confirmation' => 'Er du sikker på at du vil slette denne journaloppføringen?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
